﻿//***************************************************************************
// (C) 2011 Avery Weigh-Tronix, LLC. 
//***************************************************************************
// TITLE: WTComm ActiveX Control Test Program
// DESCR: This is the project source code for the WTComm test program. 
//        The project was written in C# using Visual Studio 2008 on a
//        Windows 7 (64-bit) computer.
//        Target platform is x86 so it should run on Win XP (32/64-bit) as
//        well as Win 7 (32/64-bit) that have .NET Framework v2.0 or newer.
//
// (C)Copyright 2011 Avery Weigh-Tronix, LLC.
//
// Contacts:
// Sales:	sales@salterbrecknell.com
//       	1-800-637-0529
//
// Service:	service@salterbrecknell.com
//      	1-800-242-2807
//
// Disclaimer:
// This test/demo program is provided as a courtesy to customers of Avery 
// Weigh-Tronix for their personal use.
//
// NO WARRANTIES: The free-of-charge software is provided “as-is” with no 
// warranties expressed or implied.
// NO LIABILITY: To the maximum extent permitted by applicable law, in no 
// event shall Avery Weigh-Tronix, its' suppliers or subsidiaries be liable 
// for any damages whatsoever (including without limitation, damages for 
// loss of business profits, business interruption, loss of business infor-
// mation, or other pecuniary loss) arising out of the installation, use or
// inability to use the software provided, even if Avery Weigh-Tronix has 
// been advised of the possibility of such damages.
// 
// This product was developed for Avery Weigh-Tronix by:
// www.vtxpro.com 
// (C)2011 Vertex Programming -- Santa Rosa, CA
//
// PROGRAMMERS NOTES:
//  1) This app originally used .NET Framework v2.0 but you can use any version.
//  2) This app was originally deployed using ClickOnce technology.
//  3) ClickOnce (on .NET Framework v2.0) does not support placing a shortcut to
//     the application on the desktop at install time. So, a CreateDesktopShortcut()
//     function was added to do this. If you use newer .NET Frameworks that do support
//     desktop icons, then you can omit this function and related namespaces.
//  4) To add a reference to the ActiveX Control:
//     * Right-Click on References in the Solution Explorer.
//     * Click on 'Add Reference...'
//     * Click on the Browse tab.
//     * Browse to find the WTComm.OCX file. On Windows 7 it is usually located
//       at c:\Windows\SysWoW64\WTComm.OCX but but it could be located in the 
//       c:\Program Files (x86)\Avery Weigh-Tronix\.. folder or one of its sub-folders.
//       Therefore, it is easiest to first do a search of your computer to find the
//       exact location of the WTComm.OCX file.
//     * Click OK to finish.
//  5) Add the namespace reference at the top of the program as follows:
//     using WTComm_OCX;
//  6) To add the ActiveX control to the Toolbox:
//     * Click on the Toolbox tab to open the Toolbox window.
//     * Right-Click on the 'All Windows Forms' section header of the Toolbox window.
//     * Click on 'Choose Items...'
//     * In the Choose Toolbox Items window, click on the COM Components tab.
//     * Scroll down and check the box next to WTComm_OCX.WTComm
//     * Click OK.
//     The WTComm ActiveX Control should now be added to the Toolbox towards the 
//     bottom of the All Windows Forms section.
//     If it does not show up, save all files in your project, exit Visual Studio and
//     then open your project again and it should be in the Toolbox.
//  7) Using the ActiveX Control:
//     ActiveX is older technology but will be supported by Microsoft operating
//     systems until Windows 8 (which will not be able to run ActiveX).
//     The WTComm ActiveX Control is not a DLL and it has no constructors. So, it
//     cannot be easily 'instantiated' like other classes. Instead, to use the control
//     you should simply drag and drop the control from the toolbox to your form.
//  8) To prevent runtime error: "Class not registered..."
//     Make sure to set Platform Target: x86 in Project Properties - Build - General
//  9) For passed True/False parameters old VB5/VB6 uses integer definitions as follows:
//     True = -1,  False = 0 (typically), but any other value is treated as false.
// 10) Values returned from function calls are not necessarily boolean defined in note 9. 
//     Instead, values returned by some functions may be defined as:
//     Pass = 1, Fail = 0  such as with the ScaleOpen() function.
//
//     Revision: 1.0.0.1
//     9/14/2013 Removed horizontal line shape on main. It required VB PowerPack to be
//     installed on PC (which may not exist). If it is not found, it causes a runtime error
//     when the app is launched.

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using System.Deployment.Application;        // for desktop application icon
using System.Reflection;                    // for desktop application icon

using WTComm_OCX;                           // to access the ActiveX control

namespace WTComm_Test
{
    public partial class MAIN : Form
    {
        private short serialPort = 1;

        public MAIN()
        {
            // IMPORTANT: To prevent runtime error: "Class not registered..." make
            // sure to set Platform Target: x86 in Project Properties - Build - General

            InitializeComponent();
            CreateDesktopShortcut();
        }

        #region ClickOnce Desktop Shortcut
        // This will create an Application Reference file (a shortcut) on the users desktop
        // if they do not already have one when the program is loaded.
        // Check for them running the deployed version before doing this, so it doesn't kick
        // it when you're running it from within the Visual Studio IDE.
        private void CreateDesktopShortcut()
        {
            if (System.Deployment.Application.ApplicationDeployment.IsNetworkDeployed)
            {
                ApplicationDeployment ad = ApplicationDeployment.CurrentDeployment;
                if (ad.IsFirstRun)  //first time user has run the app since installation or update
                {
                    Assembly code = Assembly.GetExecutingAssembly();
                    string company = string.Empty;
                    string description = string.Empty;
                    if (Attribute.IsDefined(code, typeof(AssemblyCompanyAttribute)))
                    {
                        AssemblyCompanyAttribute ascompany =
                            (AssemblyCompanyAttribute)Attribute.GetCustomAttribute(code,
                            typeof(AssemblyCompanyAttribute));
                        company = ascompany.Company;
                    }
                    if (Attribute.IsDefined(code, typeof(AssemblyDescriptionAttribute)))
                    {
                        AssemblyDescriptionAttribute asdescription =
                            (AssemblyDescriptionAttribute)Attribute.GetCustomAttribute(code,
                            typeof(AssemblyDescriptionAttribute));
                        description = asdescription.Description;
                    }
                    if (company != string.Empty && description != string.Empty)
                    {
                        string desktopPath = string.Empty;
                        desktopPath = string.Concat(
                            Environment.GetFolderPath(Environment.SpecialFolder.Desktop),
                            "\\", description, ".appref-ms");
                        string shortcutName = string.Empty;
                        shortcutName = string.Concat(
                            Environment.GetFolderPath(Environment.SpecialFolder.Programs),
                            "\\", company, "\\", description, ".appref-ms");
                        System.IO.File.Copy(shortcutName, desktopPath, true);
                    }
                }
            }
        }
        #endregion


        private void MAIN_Load(object sender, EventArgs e)
        {
            // Communications defaults:
            lstPort.SelectedIndex = 0;          // 1
            lstBaudRate.SelectedIndex = 3;      // 9600
            lstDataBits.SelectedIndex = 0;      // 7
            lstParityBit.SelectedIndex = 2;     // E
            lstStopBits.SelectedIndex = 0;      // 1

            // Basic control defaults:
            // For this demo program we will only use the RS-232 fastest synchronous mode.
            axWTComm.CommType = WT_COMMTYPE_ENUM.wtRS232;
            axWTComm.OpMode = WT_OPMODE_ENUM.wtSyncStdReso;
            axWTComm.SyncRate = WT_SYNCRATE_ENUM.wtSyncFastest;
            axWTComm.WtNotification = WT_NOTIFY_ENUM.wtEveryWeight;
        }

        private void buttonScaleOpen_Click(object sender, EventArgs e)
        {
            // Notes: 
            // The port to C# 2008 from VB6 converted Integer parameter to ref to short!?

            // Set the serial comm port
            serialPort = (short)(lstPort.SelectedIndex + 1);

            if (serialPort > 0)
            {
                axWTComm.CommPort = serialPort;
                axWTComm.Settings = lstBaudRate.SelectedItem + "," 
                                  + lstParityBit.SelectedItem + "," 
                                  + lstDataBits.SelectedItem + "," 
                                  + lstStopBits.SelectedItem;

                short tf = -1;                              // in old VB6, False = 0, True = -1
                short x = axWTComm.ScaleOpen(ref tf);       // returns 1:PASS, 0:FAIL

                if (x == 1)
                {
                    buttonScaleOpen.Enabled = false;
                    buttonScaleClosed.Enabled = true;
                }
                else
                {
                    buttonScaleOpen.Enabled = true;
                    buttonScaleClosed.Enabled = false;
                }
            }
        }

        private void buttonScaleClosed_Click(object sender, EventArgs e)
        {
            short tf = 0;                                   // in old VB6, False = 0, True = -1
            axWTComm.ScaleOpen(ref tf);

            lblZero.Visible = false;
            txtWeight.Text = "";
            txtStatus.Text = "";

            buttonScaleOpen.Enabled = true;
            buttonScaleClosed.Enabled = false;
        }

        private void MAIN_FormClosing(object sender, FormClosingEventArgs e)
        {
            short tf = 0;                                   // in old VB6, False = 0, True = -1
            axWTComm.ScaleOpen(ref tf);
        }

        private void axWTComm_OnScaleComm(object sender, EventArgs e)
        {
            // Notes:
            // 1)Simply double-click on the WTComm control icon in the design-mode to create
            //   (and access) this event handler for the control.
            // 2)This event will be generated for a weight event only if WtNotification property
            //   is set. This event will also be generated for a status event if the StatusNotification
            //   property is set.
            // 3)Several communications errors from the MSCOMM constituent control are grouped under the
            //   one error wtWTCOMM_EV_ERROR including: framing, data lost, receive buffer full, parity,
            //   transmit buffer full and DCB error.
                   
            switch (axWTComm.ScaleCommEvent)
            {
                case wtConst.wtWTCOMM_EV_WEIGHT:
                    // Weight updated (or changed)

                    // Update the weight display:
                    Single wt = (Single)axWTComm.Wt;
                    txtWeight.Text = wt.ToString();

                    // Update the weight display (alternate method):
                    // txtWeight.Text = axWTComm.WtString;

                    // Update the center-zero indicator:
                    short tf = axWTComm.AtZero;                 // in old VB6, False = 0, True = -1

                    if (tf == -1)
                        lblZero.Visible = true;
                    else
                        lblZero.Visible = false;
                    break;

                case wtConst.wtWTCOMM_EV_STATUS:
                    // Status changed
                    break;
                   
                case wtConst.wtWTCOMM_EV_OFFLINE:
                    // Scale has been set offline
                    txtStatus.Text = "OFFLINE";
                    break;
                    
                case wtConst.wtWTCOMM_EV_TIMEOUT:
                    // Scale not responding (or timed-out)
                    txtStatus.Text = "TIMEOUT";
                    break;
                    
                case wtConst.wtWTCOMM_EV_ERROR:
                    // Framing, data lost, recv buff full, xmit buff full, parity or dcb error
                    break;

                default:
                    break;
            }
        }

        private void btnZero_Click(object sender, EventArgs e)
        {
            if (axWTComm.ConnectStatus == wtConst.wtSCALE_ONLINE)
            {
                // Zero the display if it is within the allowed zero range.
                axWTComm.ZeroScale();
            }
        }
    }
}
